# The ELIT Project [![Build Status](https://travis-ci.org/emorynlp/elit.svg?branch=master)](https://travis-ci.org/emorynlp/elit) [![PyPI version](https://badge.fury.io/py/elit.svg)](https://badge.fury.io/py/elit)

The **E**mory **L**anguage **I**nformation **T**oolkit or **E**volution of **L**anguage and **I**nformation **T**echnology (ELIT) project provides:

* NLP tools readily available for research in various disciplines.
* Frameworks for fast development of efficient and robust NLP components.

The project is initiated and currently led by the [Emory NLP](http://nlp.mathcs.emory.edu) research group. It is under the [Apache 2](http://www.apache.org/licenses/LICENSE-2.0) license. Please join our group to get notifications about updates and send us your feedback.

<!--## Notes

* The python codes generally follow the PEP 8 coding style except: `E221`, `E272`, `E701`.-->